Exporting data from various systems
===================================

Pedasos
-------

Pedasos is a school management software mainly used in the
North of Germany (Schleswig-Holstein, Hamburg).

Please pay attention to the order of the imports: You should start
with the classes and end with the guardians.

1. Pedasos: Classes
2. Pedasos: Courses
3. Pedasos: Teachers
4. Pedasos: Students
5. Pedasos: Guardians 1
6. Pedasos: Guardians 2

To use these templates, you have to configure so-called *lists*
in Pedasos instance. AlekSIS provides example list definitions
to export CSV data matching the import templates.
